===========
Source Code
===========

This page provided API docs for functionality which is typically not used by users, but is used internally in the
**PyAutoGalaxy** source code.

These docs are intended for developers, or users doing non-standard computations using internal **PyAutoFit** objects.

Geometry Profiles
-----------------

.. currentmodule:: autogalaxy.profiles.geometry_profiles

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   EllProfile
   SphProfile

Operators
---------

.. currentmodule:: autolens

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   OperateImage
   OperateDeflections